@@ -1,6 +1,6 @@
 //  Gant -- A Groovy way of scripting Ant tasks.
 //
-//  Copyright © 2006-10 Russel Winder
+//  Copyright © 2006-11 Russel Winder
 //
 //  Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in
 //  compliance with the License. You may obtain a copy of the License at
@@ -18,6 +18,12 @@ import java.util.Iterator ;
 import java.util.List ;
 import java.util.Map ;
 
+//////////////////////////////////////////////////////////////////////////////////////////////////////////
+//  In Groovy 1.7.x Closure was a type, in Groovy 1.8.x Closure is a parameterized type.
+//  To support compilation against both versions of Groovy with the same source,
+//  suffer the "raw type" warnings that Eclipse issues.
+//////////////////////////////////////////////////////////////////////////////////////////////////////////
+
 import groovy.lang.Closure ;
 import groovy.util.AntBuilder ;
 
@@ -30,7 +36,7 @@ import org.apache.tools.ant.Project ;
  *  dry-run capability, and things to help support interaction between Gant and the underlying
  *  <code>Project</code>.
  *
- *  @author Russel Winder <russel@russel.org.uk>
+ *  @author Russel Winder <russel@winder.org.uk>
  */
 public class GantBuilder extends AntBuilder {
   /**
@@ -69,12 +75,12 @@ public class GantBuilder extends AntBuilder {
         sb.append ( "         ".substring ( 0 , padding ) + '[' + name + "] ") ;
         final Object[] args = (Object[]) arguments ;
         if ( args[0] instanceof Map<?,?> ) {
+          //////////////////////////////////////////////////////////////////////////////////////////////////////////
+          // Eclipse and IntelliJ IDEA warn that (Map) is not a proper cast but using the
+          // cast (Map<?,?>) causes a type check error due to the capture algorithm.
           //
-          // IntelliJ IDEA complains that (Map) is not a proper cast but using the cast (Map<?,?>) here
-          // causes a type check error.
-          //
-          //  TODO : Fix this.
-          //
+          //  TODO : Fix this rather than use a SuppressWarnings.
+          //////////////////////////////////////////////////////////////////////////////////////////////////////////
           @SuppressWarnings ( "unchecked" ) final Iterator<Map.Entry<?,?>> i = ( (Map) args[0] ).entrySet ( ).iterator ( ) ;
           while ( i.hasNext ( ) ) {
             final Map.Entry<?,?> e = i.next ( ) ;
@@ -83,9 +89,9 @@ public class GantBuilder extends AntBuilder {
           }
           sb.append ( '\n' ) ;
           getProject ( ).log ( sb.toString ( ) ) ;
-          if ( args.length == 2 ) { ( (Closure) args[1] ).call ( ) ; }
+          if ( args.length == 2 ) { ( (Closure<?>) args[1] ).call ( ) ; }
         }
-        else if ( args[0] instanceof Closure ) { ( (Closure) args[0] ).call ( ) ; }
+        else if ( args[0] instanceof Closure ) { ( (Closure<?>) args[0] ).call ( ) ; }
         else { throw new RuntimeException ( "Unexpected type of parameter to method " + name ) ; }
       }
       return null ;
