@@ -1,6 +1,6 @@
 //  Gant -- A Groovy way of scripting Ant tasks.
 //
-//  Copyright © 2006-10 Russel Winder
+//  Copyright © 2006-11 Russel Winder
 //
 //  Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in
 //  compliance with the License. You may obtain a copy of the License at
@@ -18,6 +18,12 @@ import java.util.HashSet ;
 import java.util.List ;
 import java.util.Set ;
 
+//////////////////////////////////////////////////////////////////////////////////////////////////////////
+//  In Groovy 1.7.x Closure was a type, in Groovy 1.8.x Closure is a parameterized type.
+//  To support compilation against both versions of Groovy with the same source,
+//  suffer the "raw type" warnings that Eclipse issues.
+//////////////////////////////////////////////////////////////////////////////////////////////////////////
+
 import groovy.lang.Closure ;
 import groovy.lang.DelegatingMetaClass ;
 import groovy.lang.GString ;
@@ -38,7 +44,7 @@ import org.apache.tools.ant.BuildException ;
  *  binding called during execution of the Gant specification must be logged so that when a depends happens
  *  the full closure call history is available.</p>
  *
- *  @author Russel Winder <russel@russel.org.uk>
+ *  @author Russel Winder <russel@winder.org.uk>
  */
 public class GantMetaClass extends DelegatingMetaClass {
   /**
@@ -50,7 +56,7 @@ public class GantMetaClass extends DelegatingMetaClass {
    *  Should a different data structure be used, one that is a bit more thread safe?  Arguably it is
    *  reasonable for this to be a synchronized object.</p>
    */
-  private static final Set<Closure> methodsInvoked = new HashSet<Closure> ( ) ;
+  private static final Set<Closure<?>> methodsInvoked = new HashSet<Closure<?>> ( ) ;
   /**
    *  The binding (aka global shared state) that is being used.
    */
@@ -69,7 +75,7 @@ public class GantMetaClass extends DelegatingMetaClass {
    *  @return the result of the <code>Closure</code> call, or <code>null</code> if the closure was not
    *  called.
    */
-  private Object processClosure ( final Closure closure ) {
+  private Object processClosure ( final Closure<?> closure ) {
     if ( ! methodsInvoked.contains ( closure ) ) {
       methodsInvoked.add ( closure ) ;
       return closure.call ( ) ;
@@ -86,14 +92,14 @@ public class GantMetaClass extends DelegatingMetaClass {
    */
   private Object processArgument ( final Object argument ) {
     final Object returnObject ;
-    if ( argument instanceof Closure ) { returnObject = processClosure ( (Closure) argument ) ; }
+    if ( argument instanceof Closure ) { returnObject = processClosure ( (Closure<?>) argument ) ; }
     else {
       final String errorReport = "depends called with an argument (" + argument + ") that is not a known target or list of targets." ;
       Object theArgument = argument ;
       if ( theArgument instanceof GString ) { theArgument = theArgument.toString ( ) ; }
       if ( theArgument instanceof String ) {
         final Object entry = binding.getVariable ( (String) theArgument ) ;
-        if ( ( entry != null ) && ( entry instanceof Closure ) ) { returnObject = processClosure ( (Closure) entry ) ; }
+        if ( ( entry != null ) && ( entry instanceof Closure ) ) { returnObject = processClosure ( (Closure<?>) entry ) ; }
         else { throw new RuntimeException ( errorReport ) ; }
       }
       else { throw new RuntimeException ( errorReport ) ; }
@@ -126,7 +132,7 @@ public class GantMetaClass extends DelegatingMetaClass {
       try {
         returnObject = super.invokeMethod ( object , methodName , arguments ) ;
         try {
-          final Closure closure = (Closure) binding.getVariable ( methodName ) ;
+          final Closure<?> closure = (Closure<?>) binding.getVariable ( methodName ) ;
           if ( closure != null ) { methodsInvoked.add ( closure ) ; }
         }
         catch ( final MissingPropertyException mpe ) { /* Purposefully empty */ }
@@ -173,10 +179,10 @@ public class GantMetaClass extends DelegatingMetaClass {
     return invokeMethod ( this , name , args ) ;
   }
   //////////////////////////////////////////////////////////////////////////////////////////////////////////
-  //  Groovy 1.5.x is Java 1.4 and as at 2008-07-10 Groovy 1.6.x groovy.lang.MetaClass and
-  //  groovy.lang.GroovyObject have not been marked up for Java 5 generics.  Because there is a problem that
-  //  blah(Class<?>) does not override blah(Class) -- at least according to Eclipse -- leave the Class type
-  //  without a type parameter and suffer the compilation warning.
+  //  As at 2012-05-31 it is believed that groovy.lang.DelegatingMetaClass (the invokeMethod method
+  //  anyway) has not been marked up for Java generics in any branch of Groovy (1.8, 2.0, master).
+  //  This leads to the problem that blah(Class<?>) does not override blah(Class). So we must leave
+  //  the Class type without a type parameter and suffer the compilation warning.
   //
   //  TODO : Class -> Class<?> when the Eclipse plugin and the Groovy code base allow.
   //////////////////////////////////////////////////////////////////////////////////////////////////////////
